<?php
/**
 * Blackbird MenuManager Module
 *
 * NOTICE OF LICENSE
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to contact@bird.eu so we can send you a copy immediately.
 *
 * @custom_field            Blackbird
 * @package        Blackbird_MenuManager
 * @copyright           Copyright (c) 2016 Blackbird (http://black.bird.eu)
 * @author        Blackbird Team
 */

namespace FiloBlu\ExtBlackbirdMenuManager\Block\NodeType;

use Blackbird\MenuManager\Block\NodeType\AbstractNodeTypeFront;
use Magento\Backend\Block\Template\Context;
use Magento\Cms\Model\Template\FilterProvider;
use Magento\Framework\App\ResourceConnection;
use Magento\Framework\Profiler;

/**
 * Class CustomField
 * @package FiloBlu\ExtBlackbirdMenuManager\Block\NodeType
 */
class CustomField extends AbstractNodeTypeFront
{
    protected $nodes;
    protected $custom_fieldUrls;
    protected $filterProvider;
    /**
     * @var ResourceConnection
     */
    private $connection;

    /**
     * CustomField constructor.
     * @param Context $context
     * @param ResourceConnection $connection
     * @param Profiler $profiler
     * @param FilterProvider $filterProvider
     * @param array $data
     */
    public function __construct(
        Context $context,
        ResourceConnection $connection,
        Profiler $profiler,
        FilterProvider $filterProvider,
        $data = []
    )
    {
        $this->connection = $connection;
        $this->profiler = $profiler;
        $this->filterProvider = $filterProvider;
        parent::__construct($context, $data);
    }


    public function fetchData(array $nodes)
    {
        $localNodes = [];
        $custom_fieldIds = [];
        foreach ($nodes as $node) {
            $localNodes[$node->getId()] = $node;
            $custom_fieldIds[] = (int)$node->getContent();
        }
        $this->nodes = $localNodes;
    }

    /**
     * @param $nodeId
     * @param $level
     * @param $classes
     * @param $childrenHtml
     * @param $childrenArray
     * @return string
     */
    public function getHtml($nodeId, $level, $classes, $childrenHtml, $childrenArray, $storeId)
    {
        $node = $this->nodes[$nodeId];

        $node->setUrlPath($this->getUrlNode($node));

        $url = $this->getData('url');
        $classes = $this->getIsActiveClass($url, $node, $classes, $childrenArray);

        return parent::getHtml($nodeId, $level, $classes, $childrenHtml, $childrenArray, $storeId);
    }

    /**
     * define the url of the node
     *
     * @param $node
     * @return mixed
     */
    public function getUrlNode($node)
    {
        $url = $node->getUrlPath();
        $this->setData('url', $url);

        return $url;
    }

    /**
     * @param $url
     * @return string
     * @throws \Exception
     */
    public function filterUrl($url)
    {
        return $this->filterProvider->getBlockFilter()->filter($url);
    }
}